@@ -9,6 +9,8 @@ import subprocess  # nosec
 import time
 from typing import Tuple, cast
 
+from markupsafe import escape
+
 from ..util import bytes_to_size_string, size_string_to_bytes
 from .monitor import Monitor, register
 
@@ -482,6 +484,9 @@ class MonitorCommand(Monitor):
                     "result_max settings simultaneously"
                 )
                 self.result_max = None
+        self.show_output = self.get_config_option(
+            "show_output", required_type="bool", default=False
+        )
 
         command = self.get_config_option("command", required=True, allow_empty=False)
         self.command = shlex.split(command)
@@ -502,7 +507,14 @@ class MonitorCommand(Monitor):
                         "%s < %s" % (outasinteger, self.result_max)
                     )
                 return self.record_fail("%s >= %s" % (outasinteger, self.result_max))
-            return self.record_success()
+            msg = ""
+            if self.show_output:
+                msg = escape(_out.decode("utf-8"))
+            return self.record_success(msg)
+        except subprocess.CalledProcessError as exception:
+            if self.show_output:
+                return self.record_fail(exception.output.decode("utf-8"))
+            return self.record_fail(str(exception))
         except Exception as exception:
             return self.record_fail(str(exception))
 
@@ -518,7 +530,12 @@ class MonitorCommand(Monitor):
                 " ".join(self.command),
                 self.result_max,
             )
-        return 'checking command "%s" has return status 0' % " ".join(self.command)
+        return "checking command '%s' has return status 0" % " ".join(self.command)
 
     def get_params(self) -> Tuple:
-        return (self.command, self.result_regexp_text, self.result_max)
+        return (
+            self.command,
+            self.result_regexp_text,
+            self.result_max,
+            self.show_output,
+        )
